#!/bin/bash
#
# Normally, editing this script should not be required.
# Only case is to set up JAVA_HOME if it's not allready defined.
#
# To specify an alternative jvm, edit and uncomment the following line
# JAVA_HOME=/usr/lib/java

_JAVA_EXEC="java"
if [ -n $JAVA_HOME ] ; then
    _TMP="$JAVA_HOME/bin/java"
    if [ -f "$_TMP" ] ; then
        if [ -x "$_TMP" ] ; then
            _JAVA_EXEC="$_TMP"
        else
            echo "Warning: $_TMP is not executable"
        fi
    else
        echo "Warning: $_TMP does not exist"
    fi
fi
if ! which "$_JAVA_EXEC" >/dev/null ; then
    echo "Error: No java environment found"
    exit 1
fi

#
# Resolve the location of the smartsvn installation.
# This includes resolving any symlinks.
PRG=$0
while [ -h "$PRG" ]; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '^.*-> \(.*\)$' 2>/dev/null`
    if expr "$link" : '^/' 2> /dev/null >/dev/null; then
        PRG="$link"
    else
        PRG="`dirname "$PRG"`/$link"
    fi
done

SMARTSVN_BIN=`dirname "$PRG"`

# absolutize dir
oldpwd=`pwd`
cd "${SMARTSVN_BIN}"; SMARTSVN_BIN=`pwd`
cd "${oldpwd}"; unset oldpwd

SMARTSVN_HOME=`dirname "$SMARTSVN_BIN"`
_CP="$SMARTSVN_HOME/lib/smartsvn.jar:$SMARTSVN_HOME/lib/svnkit.jar:$SMARTSVN_HOME/lib/tools.jar"
_CP="$_CP:$SMARTSVN_HOME/lib/help.jar"

#
# Where settings are stored?
#
# SmartSVN stores it's setting per default in '$HOME/.smartsvn' . If you want
# to change this (e.g. to install different SmartSVN versions on the same
# machine and under the same user account), you need to set the Java system
# property 'smartsvn.home'. You could use other system properties by
# surrounding them with '${<system-property>}'.
#
# Example:
# To tell SmartSVN to store its settings in '$HOME/.smartsvn2',
# you can use the property 'user.home', which represents the user's home
# directory.
# The following line will do the job (if uncommented):
#$_JAVA_EXEC -classpath $_CP -Dsun.io.useCanonCaches=false -Dsmartsvn.home=\${user.home}/.smartsvn2 SmartSVN
#
# To make SmartSVN a portable application you may store the settings directly
# within the installation directory. For this purpose you can use the
# system property 'smartsvn.installation' here, which refers to the
# installation root of SmartSVN.
# The following line will do the job (if uncommented):
#$_JAVA_EXEC -classpath $_CP -Dsun.io.useCanonCaches=false -Dsmartsvn.home=\${smartsvn.installation}/.smartsvn SmartSVN

$_JAVA_EXEC -classpath $_CP -Dsun.io.useCanonCaches=false -Xmx48m SmartSVN
